@@ -956,6 +956,7 @@ hash_value(int type, void *v, HASH *state)
 		state = hash_len(type, value->v_config->pow2, state);
 		state = hash_len(type, value->v_config->redc2, state);
 		state = hash_bool(type, value->v_config->tilde_ok, state);
+		state = hash_bool(type, value->v_config->tilde_space, state);
 		state = hash_bool(type, value->v_config->tab_ok, state);
 		state = hash_long(type, (long)value->v_config->quomod, state);
 		state = hash_long(type, (long)value->v_config->quo, state);
@@ -1001,6 +1002,7 @@ hash_value(int type, void *v, HASH *state)
 		state = hash_int(type, value->v_config->baseb, state);
 		state = hash_bool(type, value->v_config->redecl_warn, state);
 		state = hash_bool(type, value->v_config->dupvar_warn, state);
+		state = hash_bool(type, value->v_config->fraction_space, state);
 		break;
 
 	case V_HASH:
